@@ -1,7 +1,9 @@
 # coding=utf-8
 #
 # catkin_lint
-# Copyright (c) 2013-2021 Fraunhofer FKIE
+# Copyright 2013-2022 Fraunhofer FKIE
+#
+# SPDX-License-Identifier: BSD-3-Clause
 #
 # Redistribution and use in source and binary forms, with or without
 # modification, are permitted provided that the following conditions
@@ -12,7 +14,7 @@
 #  * Redistributions in binary form must reproduce the above copyright
 #    notice, this list of conditions and the following disclaimer in the
 #    documentation and/or other materials provided with the distribution.
-#  * Neither the name of the Fraunhofer organization nor the names of its
+#  * Neither the name of the copyright holder nor the names of its
 #    contributors may be used to endorse or promote products derived from
 #    this software without specific prior written permission.
 #
@@ -120,6 +122,8 @@ def targets(linter):
     linter.add_command_hook("set_target_properties", on_set_target_properties)
     linter.add_command_hook("add_executable", on_add_target)
     linter.add_command_hook("add_library", on_add_target)
+    linter.add_command_hook("pybind_add_module", on_add_target)
+    linter.add_command_hook("pybind11_add_module", on_add_target)
     linter.add_command_hook("target_link_libraries", on_target_link_libraries)
     linter.add_final_hook(on_final)
 
@@ -137,6 +141,15 @@ def generated_files(linter):
         for f in opts["OUTPUT"] + opts["BYPRODUCTS"]:
             info.generated_files.add(info.binary_relative_path(f))
 
+    def on_file(info, cmd, args):
+        if args[0] in ["WRITE", "APPEND", "TOUCH"] and len(args) >= 2:
+            info.generated_files.add(info.binary_relative_path(args[1]))
+        elif args[0] in ["GENERATE", "CONFIGURE"]:
+            opts, args = cmake_argparse(args, {"OUTPUT": "?"})
+            if opts["OUTPUT"]:
+                f = opts["OUTPUT"]
+                info.generated_files.add(info.binary_relative_path(f))
+
     def on_generate_export_header(info, cmd, args):
         opts, args = cmake_argparse(args, {"BASE_NAME": "?", "EXPORT_FILE_NAME": "?"})
         f = args[0] + "_export.h"
@@ -174,6 +187,7 @@ def generated_files(linter):
     linter.add_command_hook("add_custom_command", on_add_custom_command)
     linter.add_command_hook("xacro_add_xacro_file", on_xacro_add_xacro_file)
     linter.add_command_hook("xacro_add_files", on_xacro_add_files)
+    linter.add_command_hook("file", on_file)
 
 
 def source_files(linter):
@@ -649,6 +663,8 @@ def scripts(linter):
         for dirpath, filename in enumerate_package_files(info.path):
             full_filename = os.path.join(dirpath, filename)
             pkg_filename = info.source_relative_path(full_filename[len(info.path) + 1:])
+            if any(pkg_filename.startswith(s + "/") for s in info.skipped_subdirs):
+                continue
             mode = os.stat(full_filename).st_mode
             if mode & stat.S_IXUSR and not is_installed(info, pkg_filename):
                 info.report(WARNING, "UNINSTALLED_SCRIPT", script=pkg_filename)
